@@ -5,19 +5,16 @@
 */
 
 #include "AddPrinter.h"
-
 #include <config.h>
 
+#include <kde-add-printer_log.h>
+
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 
-#include <QLoggingCategory>
-
 #include <KAboutData>
 #include <KLocalizedString>
 
-Q_LOGGING_CATEGORY(PM_ADD_PRINTER, "pm.add.printer")
-
 int main(int argc, char **argv)
 {
     AddPrinter app(argc, argv);
@@ -35,6 +32,8 @@ int main(int argc, char **argv)
     about.addAuthor(QStringLiteral("Mike Noe"), i18n("Port to Qt 6 / Plasma 6"), QStringLiteral("noeerover@gmail.com"));
     KAboutData::setApplicationData(about);
 
+    qCWarning(PM_ADD_PRINTER) << i18n("NOTE: This application is deprecated and will be removed from Plasma in a future release.");
+
     QCommandLineParser parser;
     about.setupCommandLine(&parser);
 
@@ -75,7 +74,7 @@ int main(int argc, char **argv)
         if (values.size() == 2) {
             app.newPrinterFromDevice(wid, values.first(), values.last());
         } else {
-            qWarning() << "The expected input should be printer/deviceid";
+            qCWarning(PM_ADD_PRINTER) << i18n("The expected input should be printer/deviceid");
             exit(EXIT_FAILURE);
         }
     } else {
