@@ -10,10 +10,13 @@
 #include "PrinterPage.h"
 #include <QWidget>
 
-namespace Ui {
-    class PrinterBehavior;
+namespace Ui
+{
+class PrinterBehavior;
 }
 
+class QWidget;
+
 class PrinterBehavior : public PrinterPage
 {
     Q_OBJECT
