@@ -343,12 +343,6 @@ Q_SIGNALS:
                       const QString &jobName,
                       uint jobImpressionsCompleted);
 
-    void rhPrinterAdded(const QString &queueName);
-    void rhPrinterRemoved(const QString &queueName);
-    void rhQueueChanged(const QString &queueName);
-    void rhJobQueuedLocal(const QString &queueName, uint jobId, const QString &jobOwner);
-    void rhJobStartedLocal(const QString &queueName, uint jobId, const QString &jobOwner);
-
 protected:
     friend class KCupsRequest;
 
@@ -379,7 +373,6 @@ private:
 
     static KCupsConnection *m_instance;
 
-    bool m_inited = false;
     KCupsPasswordDialog *m_passwordDialog;
     QUrl m_serverUrl;
 
